@@ -3,11 +3,12 @@ import hashlib
 import re
 
 from docutils import nodes
-from docutils.parsers.rst import Directive, directives
+from docutils.parsers.rst import Directive
 from sphinx.addnodes import desc_name, desc_signature
 
 from sphinxcontrib.needs.api import add_need
 from sphinxcontrib.needs.api.exceptions import NeedsInvalidException
+from sphinxcontrib.needs.defaults import NEED_DEFAULT_OPTIONS
 from sphinxcontrib.needs.functions import (
     find_and_replace_node_content,
     resolve_dynamic_values,
@@ -53,22 +54,7 @@ class NeedDirective(Directive):
 
     required_arguments = 1
     optional_arguments = 0
-    option_spec = {
-        "id": directives.unchanged_required,
-        "status": directives.unchanged_required,
-        "tags": directives.unchanged_required,
-        "links": directives.unchanged_required,
-        "collapse": directives.unchanged_required,
-        "hide": directives.flag,
-        "title_from_content": directives.flag,
-        "style": directives.unchanged_required,
-        "layout": directives.unchanged_required,
-        "template": directives.unchanged_required,
-        "pre_template": directives.unchanged_required,
-        "post_template": directives.unchanged_required,
-        "duration": directives.unchanged_required,
-        "completion": directives.unchanged_required,
-    }
+    option_spec = NEED_DEFAULT_OPTIONS
 
     final_argument_whitespace = True
 
@@ -98,6 +84,8 @@ class NeedDirective(Directive):
         id = self.options.get("id", None)
         content = "\n".join(self.content)
         status = self.options.get("status", None)
+        if status:
+            status = status.replace("__", "")  # Support for multiline options, which must use __ for empty lines
         tags = self.options.get("tags", "")
         style = self.options.get("style", None)
         layout = self.options.get("layout", "")
@@ -300,15 +288,29 @@ def process_need_nodes(app, doctree, fromdocname):
     if not hasattr(env, "needs_all_needs"):
         return
 
-    needs = env.needs_all_needs
-
     # Call dynamic functions and replace related note data with their return values
     resolve_dynamic_values(env)
 
+    # check if we have dead links
+    check_links(env)
+
     # Create back links of common links and extra links
     for links in env.config.needs_extra_links:
         create_back_links(env, links["option"])
 
+
+def print_need_nodes(app, doctree, fromdocname):
+    """
+    Finally creates the need-node in the docurils node-tree.
+
+    :param app:
+    :param doctree:
+    :param fromdocname:
+    :return:
+    """
+    env = app.builder.env
+    needs = env.needs_all_needs
+
     for node_need in doctree.traverse(Need):
         need_id = node_need.attributes["ids"][0]
         need_data = needs[need_id]
@@ -322,6 +324,32 @@ def process_need_nodes(app, doctree, fromdocname):
         build_need(layout, node_need, app)
 
 
+def check_links(env):
+    """
+    Checks if set links are valid or are dead (referenced need does not exist.)
+    :param env: Sphinx environment
+    :return:
+    """
+    needs = env.needs_all_needs
+    extra_links = getattr(env.config, "needs_extra_links", [])
+    for need in needs.values():
+        for link_type in extra_links:
+            dead_links_allowed = link_type.get("allow_dead_links", False)
+            for link in need[link_type["option"]]:
+                if "." in link:
+                    need_id, need_part_id = link.split(".")
+                else:
+                    need_id = link
+                    need_part_id = None
+                if need_id not in needs or (
+                    need_id in needs and need_part_id and need_part_id not in needs[need_id]["parts"]
+                ):
+                    need["has_dead_links"] = True
+                    if not dead_links_allowed:
+                        need["has_forbidden_dead_links"] = True
+                    break  # One found dead link is enough
+
+
 def create_back_links(env, option):
     """
     Create back-links in all found needs.
