@@ -2,6 +2,8 @@ $(document).ready(function() {
     $('table.NEEDS_DATATABLES').DataTable( {
         dom: 'lBfrtip',
         colReorder: true,
+        scrollX: true,
+        autoWidth: false,
         buttons: [
             {
                 extend: 'colvis',
@@ -11,4 +13,5 @@ $(document).ready(function() {
         ],
         responsive: false
     });
+
 } );
