@@ -11,6 +11,8 @@ from sphinxcontrib.needs.builder import NeedsBuilder
 from sphinxcontrib.needs.defaults import (
     DEFAULT_DIAGRAM_TEMPLATE,
     LAYOUTS,
+    NEED_DEFAULT_OPTIONS,
+    NEEDEXTEND_NOT_ALLOWED_OPTIONS,
     NEEDFLOW_CONFIG_DEFAULTS,
 )
 from sphinxcontrib.needs.directives.need import (
@@ -21,9 +23,15 @@ from sphinxcontrib.needs.directives.need import (
     html_visit,
     latex_depart,
     latex_visit,
+    print_need_nodes,
     process_need_nodes,
     purge_needs,
 )
+from sphinxcontrib.needs.directives.needextend import (
+    Needextend,
+    NeedextendDirective,
+    process_needextend,
+)
 from sphinxcontrib.needs.directives.needextract import (
     Needextract,
     NeedextractDirective,
@@ -70,9 +78,11 @@ from sphinxcontrib.needs.environment import (
     install_lib_static_files,
     install_styles_static_files,
 )
+from sphinxcontrib.needs.external_needs import load_external_needs
 from sphinxcontrib.needs.functions import needs_common_functions, register_func
 from sphinxcontrib.needs.logging import get_logger
 from sphinxcontrib.needs.roles.need_count import NeedCount, process_need_count
+from sphinxcontrib.needs.roles.need_func import NeedFunc, process_need_func
 from sphinxcontrib.needs.roles.need_incoming import NeedIncoming, process_need_incoming
 from sphinxcontrib.needs.roles.need_outgoing import NeedOutgoing, process_need_outgoing
 from sphinxcontrib.needs.roles.need_part import NeedPart, process_need_part
@@ -82,7 +92,8 @@ from sphinxcontrib.needs.services.manager import ServiceManager
 from sphinxcontrib.needs.utils import INTERNALS, NEEDS_FUNCTIONS
 from sphinxcontrib.needs.warnings import process_warnings
 
-VERSION = "0.6.2"
+VERSION = "0.7.0"
+NEEDS_FUNCTIONS.clear()
 
 
 class TagsDummy:
@@ -130,7 +141,7 @@ def setup(app):
     app.add_config_value("needs_table_columns", "ID;TITLE;STATUS;TYPE;OUTGOING;TAGS", "html")
     app.add_config_value("needs_table_style", "DATATABLES", "html")
 
-    app.add_config_value("needs_role_need_template", u"{title} ({id})", "html")
+    app.add_config_value("needs_role_need_template", "{title} ({id})", "html")
     app.add_config_value("needs_role_need_max_title_length", 30, "html", types=[int])
 
     app.add_config_value("needs_extra_options", {}, "html")
@@ -164,7 +175,7 @@ def setup(app):
     app.add_config_value("needs_css", "modern.css", "html")
 
     # Prefix for need_part output in tables
-    app.add_config_value("needs_part_prefix", u"\u2192\u00a0", "html")
+    app.add_config_value("needs_part_prefix", "\u2192\u00a0", "html")
 
     # List of additional links, which can be used by setting related option
     # Values needed for each new link:
@@ -192,6 +203,8 @@ def setup(app):
 
     app.add_config_value("needs_debug_no_external_calls", False, "html", types=[bool])
 
+    app.add_config_value("needs_external_needs", [], "html")
+
     # Define nodes
     app.add_node(Need, html=(html_visit, html_depart), latex=(latex_visit, latex_depart))
     app.add_node(
@@ -206,6 +219,7 @@ def setup(app):
     app.add_node(Needgantt)
     app.add_node(Needextract)
     app.add_node(Needservice)
+    app.add_node(Needextend)
     app.add_node(NeedPart, html=(visitor_dummy, visitor_dummy), latex=(visitor_dummy, visitor_dummy))
 
     ########################################################################
@@ -223,6 +237,7 @@ def setup(app):
     app.add_directive("needimport", NeedimportDirective)
     app.add_directive("needextract", NeedextractDirective)
     app.add_directive("needservice", NeedserviceDirective)
+    app.add_directive("needextend", NeedextendDirective)
 
     ########################################################################
     # ROLES
@@ -240,6 +255,8 @@ def setup(app):
 
     app.add_role("need_count", XRefRole(nodeclass=NeedCount, innernodeclass=nodes.inline, warn_dangling=True))
 
+    app.add_role("need_func", XRefRole(nodeclass=NeedFunc, innernodeclass=nodes.inline, warn_dangling=True))
+
     ########################################################################
     # EVENTS
     ########################################################################
@@ -247,7 +264,7 @@ def setup(app):
     app.connect("env-purge-doc", purge_needs)
     app.connect("config-inited", load_config)
     app.connect("env-before-read-docs", prepare_env)
-    # app.connect('env-before-read-docs', load_config)
+    app.connect("env-before-read-docs", load_external_needs)
     app.connect("config-inited", check_configuration)
 
     # There is also the event doctree-read.
@@ -259,6 +276,8 @@ def setup(app):
     # See also https://github.com/sphinx-doc/sphinx/issues/7054#issuecomment-578019701 for an example
     app.connect("doctree-resolved", add_sections)
     app.connect("doctree-resolved", process_need_nodes)
+    app.connect("doctree-resolved", process_needextend)  # Must be done very early, as it modifies need data
+    app.connect("doctree-resolved", print_need_nodes)
     app.connect("doctree-resolved", process_needextract)
     app.connect("doctree-resolved", process_needfilters)
     app.connect("doctree-resolved", process_needlist)
@@ -272,6 +291,7 @@ def setup(app):
     app.connect("doctree-resolved", process_need_incoming)
     app.connect("doctree-resolved", process_need_outgoing)
     app.connect("doctree-resolved", process_need_count)
+    app.connect("doctree-resolved", process_need_func)
     app.connect("build-finished", process_warnings)
     app.connect("env-updated", install_lib_static_files)
 
@@ -290,7 +310,7 @@ def setup(app):
 
 def load_config(app: Sphinx, *_args):
     """
-    Register extra options and directive based on config from con.py
+    Register extra options and directive based on config from conf.py
     """
     types = app.config.needs_types
     extra_options = app.config.needs_extra_options
@@ -312,6 +332,51 @@ def load_config(app: Sphinx, *_args):
     NeedDirective.option_spec.update(extra_links)
     NeedserviceDirective.option_spec.update(extra_links)
 
+    # Update NeedextendDirective with option modifiers.
+    for key, value in NEED_DEFAULT_OPTIONS.items():
+
+        # Ignore options like "id"
+        if key in NEEDEXTEND_NOT_ALLOWED_OPTIONS:
+            continue
+
+        NeedextendDirective.option_spec.update(
+            {
+                key: value,
+                f"+{key}": value,
+                f"-{key}": directives.flag,
+            }
+        )
+
+    for key, value in extra_links.items():
+        NeedextendDirective.option_spec.update(
+            {
+                key: value,
+                f"+{key}": value,
+                f"-{key}": directives.flag,
+                f"{key}_back": value,
+                f"+{key}_back": value,
+                f"-{key}_back": directives.flag,
+            }
+        )
+
+    # "links" is not part of the extra_links-dict, so we need
+    # to set the links_back values by hand
+    NeedextendDirective.option_spec.update(
+        {
+            "links_back": NEED_DEFAULT_OPTIONS["links"],
+            "+links_back": NEED_DEFAULT_OPTIONS["links"],
+            "-links_back": directives.flag,
+        }
+    )
+    for key, value in extra_options.items():
+        NeedextendDirective.option_spec.update(
+            {
+                key: value,
+                f"+{key}": value,
+                f"-{key}": directives.flag,
+            }
+        )
+
     if title_optional or title_from_content:
         NeedDirective.required_arguments = 0
         NeedDirective.optional_arguments = 1
@@ -332,7 +397,6 @@ def prepare_env(app, env, _docname):
     """
     Prepares the sphinx environment to store sphinx-needs internal data.
     """
-    NEEDS_FUNCTIONS.clear()
 
     if not hasattr(env, "needs_all_needs"):
         # Used to store all needed information about all needs in document
@@ -368,7 +432,7 @@ def prepare_env(app, env, _docname):
         register_func(needs_func)
 
     # Own extra options
-    for option in ["hidden", "duration", "completion"]:
+    for option in ["hidden", "duration", "completion", "has_dead_links", "has_forbidden_dead_links"]:
         # Check if not already set by user
         if option not in app.config.needs_extra_options.keys():
             app.config.needs_extra_options[option] = directives.unchanged
@@ -418,7 +482,11 @@ def prepare_env(app, env, _docname):
         # Some tasks like backlink_creation need be be performed only once.
         # But most sphinx-events get called several times (for each single document
         # file), which would also execute our code several times...
-        env.needs_workflow = {"backlink_creation_links": False, "dynamic_values_resolved": False}
+        env.needs_workflow = {
+            "backlink_creation_links": False,
+            "dynamic_values_resolved": False,
+            "needs_extended": False,
+        }
         for link_type in app.config.needs_extra_links:
             env.needs_workflow["backlink_creation_{}".format(link_type["option"])] = False
 
