@@ -2,6 +2,7 @@ import json
 import os
 import shutil
 from datetime import datetime
+from typing import Any, Dict, List
 
 from docutils import nodes
 from sphinx.application import Sphinx
@@ -44,6 +45,10 @@ INTERNALS = [
     # "parent_needs",
     "parent_need",
     # "child_needs",
+    "is_external",
+    "external_css",
+    "is_modified",
+    "modifications",
 ]
 
 
@@ -82,7 +87,7 @@ def row_col_maker(
     row_col = nodes.entry(classes=["needs_" + need_key])
     para_col = nodes.paragraph()
 
-    if need_key in need_info and need_info[need_key]:
+    if need_key in need_info and need_info[need_key] is not None:
         if isinstance(need_info[need_key], (list, set)):
             data = need_info[need_key]
         else:
@@ -107,15 +112,26 @@ def row_col_maker(
             if make_ref or ref_lookup:
                 try:
                     ref_col = nodes.reference("", "")
-                    if not ref_lookup:
-                        ref_col["refuri"] = app.builder.get_relative_uri(fromdocname, need_info["docname"])
-                        ref_col["refuri"] += "#" + datum
-                    else:
+                    if make_ref:
+                        if need_info["is_external"]:
+                            # if need is external, just use the already calculated external_url
+                            ref_col["refuri"] = need_info["external_url"]
+                            ref_col["classes"].append(need_info["external_css"])
+                            row_col["classes"].append(need_info["external_css"])
+                        else:
+                            ref_col["refuri"] = app.builder.get_relative_uri(fromdocname, need_info["docname"])
+                            ref_col["refuri"] += "#" + datum
+                    elif ref_lookup:
                         temp_need = all_needs[link_id]
-                        ref_col["refuri"] = app.builder.get_relative_uri(fromdocname, temp_need["docname"])
-                        ref_col["refuri"] += "#" + temp_need["id"]
-                        if link_part:
-                            ref_col["refuri"] += "." + link_part
+                        if temp_need["is_external"]:
+                            ref_col["refuri"] = temp_need["external_url"]
+                            ref_col["classes"].append(temp_need["external_css"])
+                            row_col["classes"].append(temp_need["external_css"])
+                        else:
+                            ref_col["refuri"] = app.builder.get_relative_uri(fromdocname, temp_need["docname"])
+                            ref_col["refuri"] += "#" + temp_need["id"]
+                            if link_part:
+                                ref_col["refuri"] += "." + link_part
 
                 except KeyError:
                     para_col += text_col
@@ -145,6 +161,32 @@ def rstjinja(app: Sphinx, docname: str, source):
     source[0] = rendered
 
 
+def import_prefix_link_edit(needs: Dict[str, Any], id_prefix: str, needs_extra_links: List[Dict[str, Any]]):
+    """
+    Changes existing links to support given prefix.
+    Only link-ids get touched, which are part of ``needs`` (so are linking them).
+    Other links do not get the prefix, as there are treated as "external" links.
+
+    :param needs: Dict of all needs
+    :param id_prefix: Prefix as string
+    :param needs_extra_links: config var of all supported extra links. Normally coming from env.config.needs_extra_links
+    :return:
+    """
+    needs_ids = needs.keys()
+
+    for need in needs.values():
+        for id in needs_ids:
+            # Manipulate links in all link types
+            for extra_link in needs_extra_links:
+                if extra_link["option"] in need.keys() and id in need[extra_link["option"]]:
+                    for n, link in enumerate(need[extra_link["option"]]):
+                        if id == link:
+                            need[extra_link["option"]][n] = f"{id_prefix}{id}"
+            # Manipulate descriptions
+            # ToDo: Use regex for better matches.
+            need["description"] = need["description"].replace(id, "".join([id_prefix, id]))
+
+
 class NeedsList:
     JSON_KEY_EXCLUSIONS_NEEDS = {
         "links_back",
